@@ -254,9 +254,6 @@ def update_document(state):
         if not v and type(v) not in (float, int):
             v = None
 
-        if isinstance(state.form[k], AssetField):
-            continue
-
         setattr(seo_meta, k, v)
 
     seo_meta.update()
@@ -380,7 +377,8 @@ def store_assets(state):
                 {
                     field: state.form_data.get(field) or None
                     for field in asset_fields
-                }
+                },
+                *asset_fields
             )
 
         else:
@@ -393,8 +391,6 @@ def store_assets(state):
 
             seo_meta.update(*asset_fields)
 
-    print(assets_to_remove)
-
     if state.remove_assets:
 
         # Remove assets
